@@ -1,8 +1,9 @@
 from .cli import Cp, fprint, Logger, print_model, show_array, attar_print
 from .dll import fixer_dll
-from .utils import write_video_frame, str_to_list, read_yaml, wrd_print, download, read_txt, read_json, read_video, \
-    as_minutes, time_since, MP4ToMP3
 from .lightning import pars_model_v2, pars_model, arg_creator, max_args_to_one_arg, max_args_to_max_non_tom, \
     module_creator, TorchBaseModule, \
     iou, avg_iou, bbox_iou, kmeans, name_to_layer, accuracy, de_parallel, is_parallel, anchor_prediction, \
-    attr_exist_check_, Lang, unicode_to_ascii, normalize_string
+    attr_exist_check_
+from .nlp import Lang, unicode_to_ascii, normalize_string
+from .utils import write_video_frame, str_to_list, read_yaml, wrd_print, download, read_txt, read_json, read_video, \
+    as_minutes, time_since, mp4_to_mp3
